@@ -19,8 +19,7 @@ except OSError, e:
 	if e.errno != 17:
 		raise
 
-userLogPath = "%s/dialcentral.log" % constants._data_path_
-logging.basicConfig(level=logging.DEBUG, filename=userLogPath)
+logging.basicConfig(level=logging.DEBUG, filename=constants._user_logpath_)
 _moduleLogger.info("Dialcentral %s-%s" % (constants.__version__, constants.__build__))
 
 try:
